@@ -4,8 +4,8 @@ import pickle
 import time
 from typing import List
 import numpy as np
-from mlp.base import RNNConfigReader, BasePreprocessor, BaseRNN
-from mlp.layers import Glove6BEmbedding, FastTextEmbedding
+from dsg.base import RNNConfigReader, BasePreprocessor, BaseRNN
+from dsg.layers import Glove6BEmbedding, FastTextEmbedding
 import nltk
 from nltk.tokenize import word_tokenize
 from nltk.corpus import stopwords
